==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/selection/impl/SelectRelatedBySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.selection.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SELSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedBy;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedBySet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_SELSetImpl;

import java.util.Arrays;
import java.util.List;


public class SelectRelatedBySetImpl extends InstanceSet<SelectRelatedBySet,SelectRelatedBy> implements SelectRelatedBySet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( SelectRelatedBy selectrelatedby : this ) selectrelatedby.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public ACT_SELSet R664_is_a_ACT_SEL() throws XtumlException {
        ACT_SELSet act_selset = new ACT_SELSetImpl();
        for ( SelectRelatedBy selectrelatedby : this ) act_selset.add( selectrelatedby.R664_is_a_ACT_SEL() );
        return act_selset;
    }


    @Override
    public SelectRelatedBy nullElement() {
        return SelectRelatedByImpl.EMPTY_SELECTRELATEDBY;
    }

    @Override
    public SelectRelatedBySet emptySet() {
      return new SelectRelatedBySetImpl();
    }

    @Override
    public SelectRelatedBySet value() {
        return this;
    }

    @Override
    public List<SelectRelatedBy> elements() {
        return Arrays.asList(toArray(new SelectRelatedBy[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/selection/impl/SelectRelatedBySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.selection.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SELSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedBy;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedBySet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_SELSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SelectRelatedBySetImpl extends InstanceSet<SelectRelatedBySet,SelectRelatedBy> implements SelectRelatedBySet {

    public SelectRelatedBySetImpl() {
    }

    public SelectRelatedBySetImpl(Comparator<? super SelectRelatedBy> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( SelectRelatedBy selectrelatedby : this ) selectrelatedby.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public ACT_SELSet R664_is_a_ACT_SEL() throws XtumlException {
        ACT_SELSet act_selset = new ACT_SELSetImpl();
        for ( SelectRelatedBy selectrelatedby : this ) act_selset.add( selectrelatedby.R664_is_a_ACT_SEL() );
        return act_selset;
    }


    @Override
    public SelectRelatedBy nullElement() {
        return SelectRelatedByImpl.EMPTY_SELECTRELATEDBY;
    }

    @Override
    public SelectRelatedBySet emptySet() {
      return new SelectRelatedBySetImpl();
    }

    @Override
    public SelectRelatedBySet emptySet(Comparator<? super SelectRelatedBy> comp) {
      return new SelectRelatedBySetImpl(comp);
    }

    @Override
    public SelectRelatedBySet value() {
        return this;
    }

    @Override
    public List<SelectRelatedBy> elements() {
        return Arrays.asList(toArray(new SelectRelatedBy[0]));
    }

}
